@@ -6,10 +6,11 @@ Type annotations for budgets service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_budgets import BudgetsClient
+    from boto3.session import Session
+    from mypy_boto3_budgets.client import BudgetsClient
 
-    client: BudgetsClient = boto3.client("budgets")
+    session = Session()
+    client: BudgetsClient = session.client("budgets")
     ```
 """
 import sys
@@ -82,7 +83,7 @@ class Exceptions:
 
 class BudgetsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html)
     """
 
@@ -92,13 +93,16 @@ class BudgetsClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         BudgetsClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#can_paginate)
         """
 
@@ -112,7 +116,7 @@ class BudgetsClient(BaseClient):
         """
         Creates a budget and, if included, notifications and subscribers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.create_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.create_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_budget)
         """
 
@@ -132,7 +136,7 @@ class BudgetsClient(BaseClient):
         """
         Creates a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.create_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.create_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_budget_action)
         """
 
@@ -147,7 +151,7 @@ class BudgetsClient(BaseClient):
         """
         Creates a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.create_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.create_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_notification)
         """
 
@@ -162,7 +166,7 @@ class BudgetsClient(BaseClient):
         """
         Creates a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.create_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.create_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#create_subscriber)
         """
 
@@ -170,7 +174,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.delete_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.delete_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_budget)
         """
 
@@ -180,7 +184,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.delete_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.delete_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_budget_action)
         """
 
@@ -190,7 +194,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.delete_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.delete_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_notification)
         """
 
@@ -205,7 +209,7 @@ class BudgetsClient(BaseClient):
         """
         Deletes a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.delete_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.delete_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#delete_subscriber)
         """
 
@@ -213,7 +217,7 @@ class BudgetsClient(BaseClient):
         """
         Describes a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget)
         """
 
@@ -223,7 +227,7 @@ class BudgetsClient(BaseClient):
         """
         Describes a budget action detail.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_action)
         """
 
@@ -240,7 +244,7 @@ class BudgetsClient(BaseClient):
         """
         Describes a budget action history detail.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget_action_histories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget_action_histories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_action_histories)
         """
 
@@ -250,7 +254,7 @@ class BudgetsClient(BaseClient):
         """
         Describes all of the budget actions for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_account)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_account)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_actions_for_account)
         """
 
@@ -260,7 +264,7 @@ class BudgetsClient(BaseClient):
         """
         Describes all of the budget actions for a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget_actions_for_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_actions_for_budget)
         """
 
@@ -276,7 +280,7 @@ class BudgetsClient(BaseClient):
         """
         Describes the history for `DAILY` , `MONTHLY` , and `QUARTERLY` budgets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budget_performance_history)
         """
 
@@ -286,7 +290,7 @@ class BudgetsClient(BaseClient):
         """
         Lists the budgets that are associated with an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_budgets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_budgets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_budgets)
         """
 
@@ -296,7 +300,7 @@ class BudgetsClient(BaseClient):
         """
         Lists the notifications that are associated with a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_notifications_for_budget)
         """
 
@@ -312,7 +316,7 @@ class BudgetsClient(BaseClient):
         """
         Lists the subscribers that are associated with a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#describe_subscribers_for_notification)
         """
 
@@ -322,7 +326,7 @@ class BudgetsClient(BaseClient):
         """
         Executes a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.execute_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.execute_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#execute_budget_action)
         """
 
@@ -336,7 +340,7 @@ class BudgetsClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#generate_presigned_url)
         """
 
@@ -344,7 +348,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a budget.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.update_budget)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.update_budget)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_budget)
         """
 
@@ -364,7 +368,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a budget action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.update_budget_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.update_budget_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_budget_action)
         """
 
@@ -379,7 +383,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a notification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.update_notification)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.update_notification)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_notification)
         """
 
@@ -395,7 +399,7 @@ class BudgetsClient(BaseClient):
         """
         Updates a subscriber.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Client.update_subscriber)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.update_subscriber)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#update_subscriber)
         """
 
@@ -404,8 +408,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_action_histories"]
     ) -> DescribeBudgetActionHistoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionHistories)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionhistoriespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -413,8 +417,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_actions_for_account"]
     ) -> DescribeBudgetActionsForAccountPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForAccount)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforaccountpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -422,8 +426,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_actions_for_budget"]
     ) -> DescribeBudgetActionsForBudgetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetActionsForBudget)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetactionsforbudgetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -431,8 +435,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budget_performance_history"]
     ) -> DescribeBudgetPerformanceHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeBudgetPerformanceHistory)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetperformancehistorypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -440,8 +444,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_budgets"]
     ) -> DescribeBudgetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describebudgetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -449,8 +453,8 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_notifications_for_budget"]
     ) -> DescribeNotificationsForBudgetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describenotificationsforbudgetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
 
     @overload
@@ -458,6 +462,6 @@ class BudgetsClient(BaseClient):
         self, operation_name: Literal["describe_subscribers_for_notification"]
     ) -> DescribeSubscribersForNotificationPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/paginators.html#describesubscribersfornotificationpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/budgets.html#Budgets.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_budgets/client.html#get_paginator)
         """
