@@ -20,6 +20,7 @@ from .literals import (
     ActionSubTypeType,
     ActionTypeType,
     ApprovalModelType,
+    AutoAdjustTypeType,
     BudgetTypeType,
     ComparisonOperatorType,
     EventTypeType,
@@ -42,6 +43,7 @@ __all__ = (
     "ActionHistoryTypeDef",
     "ActionThresholdTypeDef",
     "ActionTypeDef",
+    "AutoAdjustDataTypeDef",
     "BudgetPerformanceHistoryTypeDef",
     "BudgetTypeDef",
     "BudgetedAndActualAmountsTypeDef",
@@ -78,6 +80,7 @@ __all__ = (
     "DescribeSubscribersForNotificationResponseTypeDef",
     "ExecuteBudgetActionRequestRequestTypeDef",
     "ExecuteBudgetActionResponseTypeDef",
+    "HistoricalOptionsTypeDef",
     "IamActionDefinitionTypeDef",
     "NotificationTypeDef",
     "NotificationWithSubscribersTypeDef",
@@ -137,6 +140,26 @@ ActionTypeDef = TypedDict(
     },
 )
 
+_RequiredAutoAdjustDataTypeDef = TypedDict(
+    "_RequiredAutoAdjustDataTypeDef",
+    {
+        "AutoAdjustType": AutoAdjustTypeType,
+    },
+)
+_OptionalAutoAdjustDataTypeDef = TypedDict(
+    "_OptionalAutoAdjustDataTypeDef",
+    {
+        "HistoricalOptions": "HistoricalOptionsTypeDef",
+        "LastAutoAdjustTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class AutoAdjustDataTypeDef(_RequiredAutoAdjustDataTypeDef, _OptionalAutoAdjustDataTypeDef):
+    pass
+
+
 BudgetPerformanceHistoryTypeDef = TypedDict(
     "BudgetPerformanceHistoryTypeDef",
     {
@@ -168,6 +191,7 @@ _OptionalBudgetTypeDef = TypedDict(
         "TimePeriod": "TimePeriodTypeDef",
         "CalculatedSpend": "CalculatedSpendTypeDef",
         "LastUpdatedTime": Union[datetime, str],
+        "AutoAdjustData": "AutoAdjustDataTypeDef",
     },
     total=False,
 )
@@ -635,6 +659,27 @@ ExecuteBudgetActionResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredHistoricalOptionsTypeDef = TypedDict(
+    "_RequiredHistoricalOptionsTypeDef",
+    {
+        "BudgetAdjustmentPeriod": int,
+    },
+)
+_OptionalHistoricalOptionsTypeDef = TypedDict(
+    "_OptionalHistoricalOptionsTypeDef",
+    {
+        "LookBackAvailablePeriods": int,
+    },
+    total=False,
+)
+
+
+class HistoricalOptionsTypeDef(
+    _RequiredHistoricalOptionsTypeDef, _OptionalHistoricalOptionsTypeDef
+):
+    pass
+
+
 _RequiredIamActionDefinitionTypeDef = TypedDict(
     "_RequiredIamActionDefinitionTypeDef",
     {
